@@ -33,7 +33,8 @@ use File::ShareDir ':ALL';
 use Getopt::Long;
 
 my ($speed);
-my $sharedir = dist_dir('g-language');
+my $sharedir = dist_file('g-language', 'genomes/ecoli.gbk');
+$sharedir =~ s/genomes\/ecoli.gbk//;
 my $filename = $ARGV[0] ||= "$sharedir/genomes/buchnera.gbk";
 GetOptions("ptt=s"=>\$ptt, "speed=s"=>\$speed);
 $ptt = "$sharedir/genomes/buchnera.ptt" unless($ptt);
