@@ -47,7 +47,7 @@ use G::Inspire;
 
 # import db classes
 use G::DB::SDB;
-use G::DB::GDBI;
+use G::DB::BDB;
 
 # import "odyssey" classes
 use G::Seq::AminoAcid;
@@ -167,6 +167,7 @@ push(@EXPORT, @G::System::CHI::EXPORT);
 push(@EXPORT, @G::System::ReL8::EXPORT);
 push(@EXPORT, @G::System::FuncD::EXPORT);
 push(@EXPORT, @G::DB::SDB::EXPORT);
+push(@EXPORT, @G::DB::BDB::EXPORT);
 push(@EXPORT, @SubOpt::EXPORT);
 push(@EXPORT, @G::Messenger::EXPORT);
 
