@@ -25,7 +25,7 @@
 # 
 #END_HEADER
 #
-# written by Kazuharu Arakawa <gaou@g-language.org> at
+# written by Kazuharu Arakawa <gaou@sfc.keio.ac.jp> at
 # G-language Project, Institute for Advanced Biosciences, Keio University.
 #
 
@@ -199,14 +199,13 @@ sub read_features{
 	    $transexc = 0;
 	    $num ++;
 
-	    $this->{"FEATURE$num"}->{"feature"} = $num;
-	    $this->{"FEATURE$num"}->{"type"} = $key;
-	    $this->{"FEATURE$num"}->{"on"} = 1;
+	    $this->{"FEATURE$num"}->{feature} = $num;
+	    $this->{"FEATURE$num"}->{type} = $key;
+	    $this->{"FEATURE$num"}->{on} = 1;
 	    
-	    if ($this->{"FEATURE$num"}->{"type"} eq "CDS"){
+	    if ($this->{"FEATURE$num"}->{type} eq "CDS"){
 		$cds ++;
-		$this->{"CDS$cds"}->{"on"} = 1;
-		$this->{"FEATURE$num"}->{"cds"} = $cds;
+		$this->{"FEATURE$num"}->{cds} = $cds;
 	    }
 
 	    s/\. \./\.\./g; #for (1. .2) type irregular format
@@ -219,11 +218,9 @@ sub read_features{
 	    if (/join/){
 		if (/complement\(join/){
 		    $this->{"FEATURE$num"}->{"direction"} = "complement";
-		    $this->{"CDS$cds"}->{"direction"} = "complement";
 		    s/complement//;
 		}else{
 		    $this->{"FEATURE$num"}->{"direction"} = "direct";
-		    $this->{"CDS$cds"}->{"direction"} = "direct";
 		}
 
 		my $line = $_;
@@ -251,16 +248,11 @@ sub read_features{
 		$tmpfth =~ s/c//g;
 		my @choparray = split(/\.\./, $tmpfth);
 		$this->{"FEATURE$num"}->{"start"} = shift @choparray;
-		$this->{"CDS$cds"}->{"start"} = $this->{"FEATURE$num"}->{"start"};
 		$this->{"FEATURE$num"}->{"end"} = pop @choparray;
-		$this->{"CDS$cds"}->{"end"} = $this->{"FEATURE$num"}->{"end"};
 		$this->{"FEATURE$num"}->{"join"} = $fth;
-		$this->{"CDS$cds"}->{"join"} = $fth;
-		$this->{"CDS$cds"}->{"feature"} = $num;
 
 		if ($line =~ /\:/){
 		    $this->{"FEATURE$num"}->{"partial"} = $line;
-		    $this->{"CDS$cds"}->{"partial"} = $line;
 		}
 	    }elsif (/\?/){
 		$this->{"FEATURE$num"}->{"type"} = "partial_$key";
@@ -270,22 +262,10 @@ sub read_features{
 		$this->{"FEATURE$num"}->{"direction"} = "complement";
 		$this->{"FEATURE$num"}->{"start"} = $1;
 		$this->{"FEATURE$num"}->{"end"} = $2;
-		if ($this->{"FEATURE$num"}->{"type"} eq "CDS"){
-		    $this->{"CDS$cds"}->{"direction"} = "complement";
-		    $this->{"CDS$cds"}->{"start"} = $1;
-		    $this->{"CDS$cds"}->{"end"} = $2;
-		    $this->{"CDS$cds"}->{"feature"} = $num;
-		}
 	    }elsif (/(\d+)\.\.(\d+)/){
 		$this->{"FEATURE$num"}->{"direction"} = "direct";
 		$this->{"FEATURE$num"}->{"start"} = $1;
 		$this->{"FEATURE$num"}->{"end"} = $2;
-		if ($this->{"FEATURE$num"}->{"type"} eq "CDS"){
-		    $this->{"CDS$cds"}->{"direction"} = "direct";
-		    $this->{"CDS$cds"}->{"start"} = $1;
-		    $this->{"CDS$cds"}->{"end"} = $2;
-		    $this->{"CDS$cds"}->{"feature"} = $num;
-		}
 	    }elsif (/\s+complement\((\d+)\)/){
 		$this->{"FEATURE$num"}->{"direction"} = "complement";
 		$this->{"FEATURE$num"}->{"start"} = $1;
@@ -398,7 +378,7 @@ G::IO::GenBankI
 
 =head1 AUTHOR
 
-Kazuharu Gaou Arakawa, gaou@g-language.org
+Kazuharu Arakawa, gaou@sfc.keio.ac.jp
 
 =head1 SEE ALSO
 
