@@ -33,6 +33,7 @@ package G::Messenger;
 
 use strict;
 use Cwd;
+use Data::Dumper;
 
 if ('MSWin32' eq $^O){
     eval(require Win32::InternetExplorer::Window);
@@ -55,8 +56,11 @@ require Exporter;
 	     msg_term_console
 	     msg_gimv
 	     msg_set_gimv
+	     say
+	     p
+	     puts
 );
-$VERSION = '0.10';
+$VERSION = '0.20';
 
 
 #::::::::::::::::::::::::::::::
@@ -75,6 +79,18 @@ my $gimv = 'gimv';
 #           Methods
 #::::::::::::::::::::::::::::::
 
+sub p{
+    print Dumper(@_), "\n";
+}
+
+sub puts{
+    print @_, "\n";
+}
+
+sub say{
+    print join(',', @_), "\n";
+}
+
 sub msg_gimv{
     my $file = shift;
     my $time = 'gimv' . time();
