@@ -48,12 +48,13 @@ require G::IO::GenBankI;
 require G::IO::GenBankO;
 require G::IO::FastaI;
 require G::IO::EmblI;
+require G::DB::BDBI;
 
 use File::Basename;
 use File::ShareDir ':ALL';
 
-our @ISA = qw(G::Prelude G::IO::GenBankI G::IO::GenBankO);
-our $VERSION = '1.7.2';
+our @ISA = qw(G::Prelude G::IO::GenBankI G::IO::GenBankO G::DB::BDBI);
+our $VERSION = '1.7.3';
 
 #::::::::::::::::::::::::::::::
 #          Perldoc
